# bagheera-python [![Build Status](https://travis-ci.org/bagheera-lang/bagheera-python.svg?branch=main)](https://travis-ci.org/bagheera-lang/bagheera-python) [![Documentation Status](https://readthedocs.org/projects/bagheera-python/badge/?version=main)](https://bagheera-python.readthedocs.io/en/main/?badge=main)


An python implementation of the bagheera programming langugage
